@@ -23,6 +23,7 @@ sys.path.insert(
     os.path.join(os.path.dirname(__file__), "utils")
 )
 import random
+import copy
 import torch
 import numpy as np
 from time import time
@@ -156,7 +157,7 @@ def do_observe(
 	try:
 		optimizer.observe(
 			next_microarchitecture_embeddings,
-			objective_values[-len(next_microarchitecture_embeddings):]
+			copy.deepcopy(objective_values[-len(next_microarchitecture_embeddings):])
 		)
 	except Exception as e:
 		logger.warning(
@@ -179,7 +180,6 @@ def do_experiment_impl(
 	explored_microarchitecture_embeddings = []
 	objective_values = []
 	hv = HyperVolume(problem.reference_point)
-	golden_hypervolume = hv.compute(problem.pareto_frontier)
 
 	for i in range(num_of_queries):
 		next_microarchitecture_embeddings = do_suggest(
@@ -211,11 +211,9 @@ def do_experiment_impl(
 		logger.info(
 			"[INFO]: summary for {}-th query, " \
 			"current Pareto hypervolume: {}, " \
-			"Pareto hypervolume difference: {}, " \
 			"cost: {}.".format(
 				i + 1,
 				curr_hypervolume,
-				golden_hypervolume - curr_hypervolume,
 				np.sum([
 						np.sum(suggest_time),
 						np.sum(evaluation_time),
@@ -235,10 +233,8 @@ def do_experiment_impl(
 	logger.info(
 		"[INFO]: summary for the solution, " \
 		"the best Pareto hypervolume: {}, " \
-		"the best Pareto hypervolume difference: {} " \
 		"cost: {}.".format(
 			curr_hypervolume,
-			golden_hypervolume - curr_hypervolume,
 			np.sum([
 					np.sum(suggest_time),
 					np.sum(evaluation_time),
@@ -248,7 +244,7 @@ def do_experiment_impl(
 		)
 	)
 
-	return (explored_microarchitecture_embeddings, objective_values, golden_hypervolume - curr_hypervolume), \
+	return (explored_microarchitecture_embeddings, objective_values, curr_hypervolume), \
 		(suggest_time, evaluation_time, observe_time)
 
 
@@ -279,7 +275,7 @@ def save_experiment(args, solution_settings, explored_result, timing):
 	save_dict["solution-settings"] = solution_settings
 	save_dict["explored-microarchitecture-embedding"] = explored_result[0]
 	save_dict["objective-values"] = explored_result[1]
-	save_dict["Pareto hypervolume difference"] = explored_result[2]
+	save_dict["Pareto hypervolume"] = explored_result[2]
 	save_dict["suggest-time"] = timing[0]
 	save_dict["evaluate-time"] = timing[1]
 	save_dict["observe-time"] = timing[2]
